Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1804)

Unified Diff: Source/core/testing/DictionaryTest.h

Issue 534133002: [WIP] bindings: Introduce PropertyBag (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/page/EventSource.cpp ('k') | Source/core/testing/DictionaryTest.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/testing/DictionaryTest.h
diff --git a/Source/core/testing/DictionaryTest.h b/Source/core/testing/DictionaryTest.h
index 009dfc51b3383abe56b8303a8f734699348c6641..7c368c19f65e0db8f4a286d57ed221a7ac8ae7c0 100644
--- a/Source/core/testing/DictionaryTest.h
+++ b/Source/core/testing/DictionaryTest.h
@@ -7,6 +7,7 @@
#include "bindings/core/v8/Nullable.h"
#include "bindings/core/v8/ScriptWrappable.h"
+#include "core/dom/Element.h"
#include "platform/heap/Handle.h"
#include "wtf/text/WTFString.h"
@@ -36,13 +37,22 @@ private:
void reset();
// The reason to use Nullable<T> is convenience; we use Nullable<T> here to
- // record whether the member field is set or not. |stringMember| isn't
- // wrapped with Nullable because |stringMember| has a non-null default value
- Nullable<unsigned> m_longMember;
+ // record whether the member field is set or not. Some members are not
+ // wrapped with Nullable because:
+ // - |longMemberWithDefault| has a non-null default value
+ // - String and PtrTypes can express whether they are null
+ Nullable<int> m_longMember;
+ int m_longMemberWithDefault;
+ Nullable<int> m_longOrNullMember;
+ Nullable<int> m_longOrNullMemberWithDefault;
+ Nullable<bool> m_booleanMember;
+ Nullable<double> m_doubleMember;
String m_stringMember;
- Nullable<bool> m_booleanOrNullMember;
- Nullable<double> m_doubleOrNullMember;
+ String m_stringMemberWithDefault;
Nullable<Vector<String> > m_stringSequenceMember;
+ Nullable<Vector<String> > m_stringSequenceOrNullMember;
+ RefPtrWillBeMember<Element> m_elementMember;
+ RefPtrWillBeMember<Element> m_elementOrNullMember;
};
} // namespace blink
« no previous file with comments | « Source/core/page/EventSource.cpp ('k') | Source/core/testing/DictionaryTest.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698